@@ -15,8 +15,7 @@ self_fns = {
 'file_in':'entry',
 'file_out':'entry',
 'save_path':'entry',
-'Wshow_arr':'value',
-'data_is_loaded':'value'}
+'Wshow_arr':'value'}
 
 oct_add_opts = ['0','1','2','3','4','5']
 scale_type_opts = ['Chromatic (12/oct)','Major scale (7/oct)','Minor scale (7/oct)', 
